/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {
dojo.provide("com.ibm.team.process.web.ui.internal.ProjectAreaApplication");

dojo.require("net.jazz.ajax.toolbox.lang.internal.Lang");
dojo.require("net.jazz.ajax.ui.internal.Dialog");

dojo.require("com.ibm.team.repository.web.client.init.InitializationData");
dojo.require("com.ibm.team.repository.web.client.internal.RepositoryClient");
dojo.require("com.ibm.team.repository.web.client.session.Session");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.require("com.ibm.team.repository.web.ui.internal._JazzApplication");
dojo.require("com.ibm.team.repository.web.ui.internal.Footer");
dojo.require("com.ibm.team.repository.web.ui.internal.Header");

var checkNotNull 	= net.jazz.ajax.toolbox.lang.checkNotNull;
var checkNotEmpty 	= net.jazz.ajax.toolbox.lang.checkNotEmpty;
var isGuest			= com.ibm.team.repository.web.client.session.isGuest;

var _JazzApplication        = com.ibm.team.repository.web.ui.internal._JazzApplication;
var Footer					= com.ibm.team.repository.web.ui.internal.Footer;
var Header					= com.ibm.team.repository.web.ui.internal.Header;
var InitializationData      = com.ibm.team.repository.web.client.init.InitializationData;
var PageContainer			= net.jazz.ajax.ui.PageContainer;
var PlatformUI				= net.jazz.ajax.ui.PlatformUI;
var RepositoryClient 		= com.ibm.team.repository.web.client.internal.RepositoryClient;
var ServiceResponseHandler	= com.ibm.team.repository.web.transport.ServiceResponseHandler;
var Dialog                  = net.jazz.ajax.ui.internal.Dialog;

function getProjectAreaName(){
	//dojo.lang.assert(typeof com.ibm.team.process.web.projectArea != "undefined", "ProjectArea has not been initialized correctly");
	var paName = com.ibm.team.process.web.projectArea.name;
	//if (paName && dojo.trim(paName.toLowerCase()) === "jazz project") {
	//	return "The Jazz Project";
	//}
	return paName;
}

dojo.declare("com.ibm.team.process.web.ui.internal.ProjectAreaApplication", _JazzApplication, {
	
	init: function() {
		var srh = new ServiceResponseHandler(
			this, "_fetchInitDataSuccess", "_fetchInitDataFailure");
		RepositoryClient.getInitializationData(srh);
	},
	
	_fetchInitDataSuccess: function(initializationData) {
		checkNotNull(initializationData, "initializationData");
		
		var loadSuccess = this._loadInitializationData(initializationData);
		if (!loadSuccess) {
			return;
		}
		// init UI in superclass
		var args = {
			label: getProjectAreaName(),
			showLoginPanel: true,
			projectAreas: this.projectAreas,
			archived: com.ibm.team.process.web.projectArea.archived
		};
		this._initUI(args);
		PlatformUI.getWorkbench()._setDefaultTitle("IBM Rational Team Concert");
		ProjectAreaApplication.superclass.start.call(this);
	},
	
	_loadInitializationData: function(initializationData) {
		InitializationData._load(initializationData);
		
		// set the global var for the logged-in contributor
		try {
			dojo.setObject(
				"com.ibm.team.repository.web.client.internal.AUTHENTICATED_CONTRIBUTOR",
				InitializationData.get("com.ibm.team.repository.service.currentContributorInitializer").currentContributor);
		} catch (e) {
			document.title = "Error Loading User";
			var content = document.createElement("div");
			content.style.padding = "1em";
			var mainContent = document.createElement("div");
			mainContent.appendChild(document.createTextNode("An error was encountered attempting to fetch the authenticated user from the repository.  This is often caused by a problem connecting to the database.  Please contact your administator."));
			var adminContent = document.createElement("div");
			adminContent.style.paddingTop = "8px";
			adminContent.appendChild(document.createTextNode("If you have JazzAdmins privileges you can investigate the problem in the "));
			var link = document.createElement("a");
			link.href = net.jazz.ajax._contextRoot + "/admin";
			link.appendChild(document.createTextNode("Jazz Admin Web UI"));
			adminContent.appendChild(link);
			adminContent.appendChild(document.createTextNode("."));
			content.appendChild(mainContent);
			content.appendChild(adminContent);
			var dialog = new Dialog({primaryTitle: "Error Loading User", contentNode: content});
			return;
		}
		
		// if the user is the guest user and we're in HTTPS mode, display the
		// appropriate error
		if(isGuest() && window.location.href.match(/^https/)) {
			alert("Error logging in. There is a user id mismatch between the Jazz repository and the authentication server.  Please contact your system administrator.");
			return false; // early return
		}
		
		// set the global far for the current project area based on the last
		// segment of the document's URI and the set of project areas in the
		// repository
		var pathname = window.location.pathname;
		var projectName = pathname.substring(pathname.lastIndexOf('/')+1);
		var projectAreas = InitializationData.get("com.ibm.team.process.service.projectAreaWebUIInitializionData").projectAreas;
		this.projectAreas = projectAreas;
		var projectArea = dojo.setObject("com.ibm.team.process.web.projectArea", {});
		for (var i = 0; i < projectAreas.length; i++) {
			var decodedName = decodeURI(projectName);
			// decodeURI does not properly decode %3F to "?".  We need to force the decoding here.
			decodedName = decodedName.replace(/%3F/g,"?");
			if (projectAreas[i].name == decodedName) {
				projectArea.itemId = projectAreas[i].itemId;
				projectArea.name = projectAreas[i].name;
				projectArea.archived = projectAreas[i].archived;
				break;
			}
		}
		
		// if we couldn't find a project area for the current URI, redirect to
		// root web UI
		if (!projectArea.itemId) {
			alert("There is no project area named '" + projectName + "' in the repository; redirecting to project area list page.")
			var webBaseURL = pathname.substring(0, pathname.lastIndexOf('/'));
			webBaseURL = webBaseURL.substring(0, webBaseURL.lastIndexOf('/'));
			var url = window.location.protocol + "//" + window.location.host + webBaseURL;
			window.location.href = url;
			return false;
		}
		
		// store the configuration properties in global vars with corresponding
		// names
		var configProperties = InitializationData.get("com.ibm.team.repository.service.configPropertyInitializer");
		for (var propName in configProperties) {
			var propVal = configProperties[propName];
			dojo.setObject(propName, propVal);
		}
		return true; // load succeeded
	},
	
	_fetchInitDataFailure: function(errorObject) {
		if(errorObject.status != 401)
			throw new Error("Could not init workbench.  Error fetching initialization data: " + errorObject.message);
		
		var guestAccessIsAllowed= ws.allow.guest.access === "true";
		
		// TODO factor http/https logic into a common place
		var isHttp= location.href.match(/^https/) === null;
		
		var message= "Invalid username or password.";
		
		if (isHttp) {
			// if login failed in HTTP mode, redirect to HTTPS mode to force
			// the user to log in
			alert(message);
			window.location = "https://" + window.location.hostname + ":" + com.ibm.team.repository.server.repourl.port.https + window.location.pathname + window.location.search + window.location.hash;
		} else if (guestAccessIsAllowed) {
			// if login failed in HTTPS mode and guest access is allowed,
			// redirect to HTTP mode
			alert(message + " You may use Jazz as a guest user.");
			window.location = "http://" + window.location.hostname + ":" + com.ibm.team.repository.server.repourl.port.http + window.location.pathname + window.location.search + window.location.hash;
		} else {
			// otherwise just alert the user that login failed
			alert(message);
		}
	}
	
});

var ProjectAreaApplication = com.ibm.team.process.web.ui.internal.ProjectAreaApplication;

})();
